      FUNCTION AREAL(COORD,RAD,NBALL,K)                                 GDH0897
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)                               GDH0897
      INCLUDE 'SIZES.i'                                                 GDH0897
      PARAMETER (MXSS=2*NUMATM+1)                                       GDH0897
C ----------------------------------------------------------------------GDH0897
C     ACCESSIBLE SOLID ANGLE OF SPHERES (RADIANS). ANALYTICAL.          GDH0897
C     ALLOW MULTIPLE CONNECTED COMPONENTS ON A SPHERE.                  GDH0897
C     REGULARIZE RARE EVENTS (POINTS SHARED BY MORE THAN 3 SPHERES)     GDH0897
C     BY A SMALL PERTURBATION ON RADIUS.                                GDH0897
C  INPUT                                                                GDH0897
C     COORD(3,NBALL): CARTESIAN COORDINATES OF CENTRES.                 GDH0897
C     RAD(NBALL)    : RADII.                                            GDH0897
C     NBALL         : NUMBER OF SPHERES.                                GDH0897
C     K             : No OF THE SPHERE STUDIED.                         GDH0897
C  OUTPUT                                                               GDH0897
C     AREAL         : ACCESSIBLE SOLID ANGLE FOR SPHERE No K.           GDH0897
C     D. LIOTARD, DECEMBER 1992.                                        GDH0897
C ----------------------------------------------------------------------GDH0897
      LOGICAL FREEIJ,FREEJI,CONECT,LPOLY                                GDH0897
      DIMENSION COORD(3,*),RAD(*)                                       GDH0897
      COMMON /SCRCHR/ CTHETA(NUMATM,NUMATM),STHETA(NUMATM),SIT(NUMATM)  GDH0897
     1               ,COSN1(NUMATM,NUMATM),COSN2(NUMATM,NUMATM)         GDH0897
     2               ,COSN3(NUMATM,NUMATM),WORK(MXSS)                   GDH0897
     3               ,FILL(6*MAXPAR**2-NUMATM*(4*NUMATM+4))             GDH0897
      COMMON /VOLCOM/ RLIO(NUMATM,NUMATM)                               GDH0897
      DIMENSION LAB(NUMATM),NCNCT(MXSS,NUMATM),CONECT(NUMATM,NUMATM)    GDH0897
C     EPSI:THRESHOLD TO AVOID DRAMATIC CONSEQUENCES OF ROUND-OFF ERRORS,GDH0897
C     MUST BE GREATER THAN THE POOREST OF RELATIVE ERRORS ON FUNCTIONS: GDH0897
C     SQRT, ATAN.                                                       GDH0897
      DATA EPSI /1.D-11/                                                GDH0897
      SAVE                                                              GDH0897
      TWOPI=PI+PI                                                       GDH0897
      FOURPI=TWOPI+TWOPI                                                GDH0897
      RK=RAD(K)                                                         GDH0897
      IF (RK.LE.0D0) THEN                                               GDH0897
         AREAL=0D0                                                      GDH0897
         RETURN                                                         GDH0897
      ELSE                                                              GDH0897
C        PRESET ACCESSIBLE SOLID ANGLES TO "FREE" SPHERES.              GDH0897
         AREAL=FOURPI                                                   GDH0897
      ENDIF                                                             GDH0897
   10 NCROSS=0                                                          GDH0897
      EPSK=EPSI*RK                                                      GDH0897
C     CHECK IF SPHERE K NOT BURIED; SET UP FLAG FOR OVERLAP OF K.       GDH0897
C     -------------------------------------------------------------     GDH0897
      DO 20 I=1,NBALL                                                   GDH0897
      IF (I.EQ.K.OR.RAD(I).LE.0D0) GOTO 20                              GDH0897
      IF (RK+RAD(I)-RLIO(I,K).LT.EPSK) GOTO 20                          GDH0897
      IF (RLIO(I,K)-ABS(RK-RAD(I)).LT.EPSK) THEN                        GDH0897
         IF (RK.LE.RAD(I)) THEN                                         GDH0897
C           SPHERE K IMBEDDED IN SPHERE I                               GDH0897
            AREAL=0D0                                                   GDH0897
            RETURN                                                      GDH0897
         ENDIF                                                          GDH0897
      ELSE                                                              GDH0897
         NCROSS=NCROSS+1                                                GDH0897
         NCNCT(NCROSS,1)=I                                              GDH0897
      ENDIF                                                             GDH0897
   20 CONTINUE                                                          GDH0897
      IF (NCROSS.EQ.0) THEN                                             GDH0897
C        THE SPHERE K IS FREE.                                          GDH0897
         RETURN                                                         GDH0897
      ENDIF                                                             GDH0897
C     SET UP DATA FOR SPHERICAL SEGMENTS (SS).                          GDH0897
C     ----------------------------------------                          GDH0897
      XK=COORD(1,K)                                                     GDH0897
      YK=COORD(2,K)                                                     GDH0897
      ZK=COORD(3,K)                                                     GDH0897
      RKINV=0.5D0/RK                                                    GDH0897
      RK2=RK**2                                                         GDH0897
      DO 22 I=1,NCROSS                                                  GDH0897
      LI=NCNCT(I,1)                                                     GDH0897
      RIKINV=1.D0/RLIO(LI,K)                                            GDH0897
C     COSINE OF HALF-ANGLE OF CONE.                                     GDH0897
      CTHETA(I,I)=RKINV*(RLIO(LI,K)+(RK2-RAD(LI)**2)*RIKINV)            GDH0897
      STHETA(I)=SQRT(1.D0-CTHETA(I,I)**2)                               GDH0897
      CONECT(I,I)=.FALSE.                                               GDH0897
C     DIRECTOR COSINES OF VECTOR KI.                                    GDH0897
      COSN1(I,I)=(COORD(1,LI)-XK)*RIKINV                                GDH0897
      COSN2(I,I)=(COORD(2,LI)-YK)*RIKINV                                GDH0897
      COSN3(I,I)=(COORD(3,LI)-ZK)*RIKINV                                GDH0897
   22 CONTINUE                                                          GDH0897
C     CONNECTIVITY MATRIX BETWEEN SS.                                   GDH0897
C     -------------------------------                                   GDH0897
C     TRUE IIF CONNECTED. DIAGONAL=TRUE IIF IMBEDDED.                   GDH0897
      DO 40 I=2,NCROSS                                                  GDH0897
      DO 30 J=1,I-1                                                     GDH0897
      IF (CONECT(J,J)) GOTO 30                                          GDH0897
      CISJ=CTHETA(I,I)*STHETA(J)                                        GDH0897
      SICJ=STHETA(I)*CTHETA(J,J)                                        GDH0897
      SISJ=STHETA(I)*STHETA(J)                                          GDH0897
C     COSINES OF ANGLES BETWEEN VECTOR KI AND KJ.                       GDH0897
      CTHETA(J,I)=COSN1(I,I)*COSN1(J,J)                                 GDH0897
     .+COSN2(I,I)*COSN2(J,J)+COSN3(I,I)*COSN3(J,J)                      GDH0897
      TIJ=CTHETA(J,I)-CTHETA(I,I)*CTHETA(J,J)                           GDH0897
      IF (TIJ.GT.SISJ-EPSI*ABS(CISJ-SICJ)) THEN                         GDH0897
         IF (CTHETA(J,J).GT.CTHETA(I,I)) THEN                           GDH0897
C           SS J IMBEDDED IN SS I                                       GDH0897
            CONECT(J,J)=.TRUE.                                          GDH0897
         ELSE                                                           GDH0897
C           SS I IMBEDDED IN SS J                                       GDH0897
            CONECT(I,I)=.TRUE.                                          GDH0897
            GOTO 40                                                     GDH0897
         ENDIF                                                          GDH0897
      ELSE                                                              GDH0897
         EPSIJ=EPSI*(SICJ+CISJ)                                         GDH0897
         IF (SICJ+CISJ.GE.0D0) THEN                                     GDH0897
            CONECT(J,I)=TIJ.GT.EPSIJ-SISJ                               GDH0897
         ELSE                                                           GDH0897
            IF (TIJ.LE.-SISJ-EPSIJ) THEN                                GDH0897
C              SPHERE K FULLY COVERED BY SS I PLUS SS J                 GDH0897
               AREAL=0D0                                                GDH0897
               RETURN                                                   GDH0897
            ELSE                                                        GDH0897
               CONECT(J,I)=.TRUE.                                       GDH0897
            ENDIF                                                       GDH0897
         ENDIF                                                          GDH0897
         CONECT(I,J)=CONECT(J,I)                                        GDH0897
      ENDIF                                                             GDH0897
   30 CONTINUE                                                          GDH0897
   40 CONTINUE                                                          GDH0897
C     SUM THE CONTRIBUTIONS FROM ISOLATED SS.                           GDH0897
C     ---------------------------------------                           GDH0897
      ASLICE=0D0                                                        GDH0897
      NCLUST=0                                                          GDH0897
      DO 60 I=1,NCROSS                                                  GDH0897
      IF (CONECT(I,I)) GOTO 60                                          GDH0897
      DO 50 J=1,NCROSS                                                  GDH0897
      IF (CONECT(J,J)) GOTO 50                                          GDH0897
      IF (CONECT(J,I)) THEN                                             GDH0897
         NCLUST=NCLUST+1                                                GDH0897
C        LABEL OF NON-ISOLATED SS: LAB                                  GDH0897
         LAB(NCLUST)=I                                                  GDH0897
C        PREPARE DATA FOR FURTHER USE                                   GDH0897
         WORK(NCLUST)=CTHETA(I,I)+EPSI*STHETA(I)                        GDH0897
         WORK(NCLUST+NCROSS)=CTHETA(I,I)-EPSI*STHETA(I)                 GDH0897
         GOTO 60                                                        GDH0897
      ENDIF                                                             GDH0897
   50 CONTINUE                                                          GDH0897
      ASLICE=ASLICE+1D0-CTHETA(I,I)                                     GDH0897
   60 CONTINUE                                                          GDH0897
      ASLICE=TWOPI*ASLICE                                               GDH0897
      IF (NCLUST.EQ.0) THEN                                             GDH0897
C        NO CLUSTER OF SS REMAINS ON SPHERE K.                          GDH0897
         AREAL=FOURPI-ASLICE                                            GDH0897
         RETURN                                                         GDH0897
      ENDIF                                                             GDH0897
C     "FREE" INTERSECTIONS BETWEEN CLUSTERED SS.                        GDH0897
C     ------------------------------------------                        GDH0897
      NFREE=0                                                           GDH0897
      NCNCT(MXSS,LAB(1))=0                                              GDH0897
      DO 80 I=2,NCLUST                                                  GDH0897
      LI=LAB(I)                                                         GDH0897
      NCNCT(MXSS,LI)=0                                                  GDH0897
      DO 80 J=1,I-1                                                     GDH0897
      LJ=LAB(J)                                                         GDH0897
      IF (CONECT(LJ,LI)) THEN                                           GDH0897
C        DIRECTOR COSINES OF INTERSECTION POINTS BETWEEN SS             GDH0897
         SIN2IJ=1.D0/(1.D0-CTHETA(LJ,LI)**2)                            GDH0897
         AIJ=(CTHETA(LI,LI)-CTHETA(LJ,LJ)*CTHETA(LJ,LI))*SIN2IJ         GDH0897
         BIJ=(CTHETA(LJ,LJ)-CTHETA(LI,LI)*CTHETA(LJ,LI))*SIN2IJ         GDH0897
         COS1=AIJ*COSN1(LI,LI)+BIJ*COSN1(LJ,LJ)                         GDH0897
         COS2=AIJ*COSN2(LI,LI)+BIJ*COSN2(LJ,LJ)                         GDH0897
         COS3=AIJ*COSN3(LI,LI)+BIJ*COSN3(LJ,LJ)                         GDH0897
         CIJ=SQRT((1D0-AIJ*CTHETA(LI,LI)-BIJ*CTHETA(LJ,LJ))*SIN2IJ)     GDH0897
         WORK1=CIJ*(COSN2(LI,LI)*COSN3(LJ,LJ)-COSN3(LI,LI)*COSN2(LJ,LJ))GDH0897
         WORK2=CIJ*(COSN3(LI,LI)*COSN1(LJ,LJ)-COSN1(LI,LI)*COSN3(LJ,LJ))GDH0897
         WORK3=CIJ*(COSN1(LI,LI)*COSN2(LJ,LJ)-COSN2(LI,LI)*COSN1(LJ,LJ))GDH0897
C        INTERSECTION PIJ                                               GDH0897
         COSN1(LI,LJ)=COS1+WORK1                                        GDH0897
         COSN2(LI,LJ)=COS2+WORK2                                        GDH0897
         COSN3(LI,LJ)=COS3+WORK3                                        GDH0897
         FREEIJ=.TRUE.                                                  GDH0897
C        INTERSECTION PJI                                               GDH0897
         COSN1(LJ,LI)=COS1-WORK1                                        GDH0897
         COSN2(LJ,LI)=COS2-WORK2                                        GDH0897
         COSN3(LJ,LI)=COS3-WORK3                                        GDH0897
         FREEJI=.TRUE.                                                  GDH0897
C        SET UP TABLE OF FREE INTERSECTIONS BETWEEN SS.                 GDH0897
C        HERE IS THE L**3 PART OF THE CODE (L= MEAN VALUE OF NEIGHBORS) GDH0897
         DO 70 L=1,NCLUST                                               GDH0897
         IF (L.EQ.I.OR.L.EQ.J) GOTO 70                                  GDH0897
         LL=LAB(L)                                                      GDH0897
         IF (CONECT(LL,LI).AND.CONECT(LL,LJ)) THEN                      GDH0897
            IF (FREEJI) THEN                                            GDH0897
               CHEK=COSN1(LJ,LI)*COSN1(LL,LL)+COSN2(LJ,LI)*COSN2(LL,LL) GDH0897
     .             +COSN3(LJ,LI)*COSN3(LL,LL)                           GDH0897
               IF (CHEK.GT.WORK(L)) THEN                                GDH0897
                  FREEJI=.FALSE.                                        GDH0897
               ELSE                                                     GDH0897
                  AMOUP=ABS(WORK(L+NCROSS)-CHEK)                        GDH0897
                  IF (CHEK.GE.WORK(L+NCROSS)) THEN                      GDH0897
C                 SPHERES K, LAB(I), LAB(J), LAB(L) SHARE A POINT (AT   GDH0897
C                 THRESHOLD EPSI IN ANGLE). INCREASE THE RADIUS OF      GDH0897
C                 SPHERE K AND RESTART STUDY OF SPHERE K.               GDH0897
                  RK=RK*(1D0+4D0*EPSI)                                  GDH0897
                  GOTO 10                                               GDH0897
                  ENDIF                                                 GDH0897
               ENDIF                                                    GDH0897
            ENDIF                                                       GDH0897
            IF (FREEIJ) THEN                                            GDH0897
               CHEK=COSN1(LI,LJ)*COSN1(LL,LL)+COSN2(LI,LJ)*COSN2(LL,LL) GDH0897
     .             +COSN3(LI,LJ)*COSN3(LL,LL)                           GDH0897
               IF (CHEK.GT.WORK(L)) THEN                                GDH0897
                  FREEIJ=.FALSE.                                        GDH0897
               ELSE IF (CHEK.GE.WORK(L+NCROSS)) THEN                    GDH0897
                  RK=RK*(1D0+4D0*EPSI)                                  GDH0897
                  GOTO 10                                               GDH0897
               ENDIF                                                    GDH0897
            ENDIF                                                       GDH0897
            IF (.NOT.(FREEIJ.OR.FREEJI)) GOTO 80                        GDH0897
         ENDIF                                                          GDH0897
   70    CONTINUE                                                       GDH0897
C        ONE OR TWO FREE INTERSECTIONS FOUND. UPDATE TABLE.             GDH0897
         CTHETA(LI,LJ)=CTHETA(LJ,LI)                                    GDH0897
         IF (FREEJI) THEN                                               GDH0897
            NFREE=NFREE+1                                               GDH0897
            M=NCNCT(MXSS,LI)+1                                          GDH0897
            NCNCT(M,LI)=LJ                                              GDH0897
            NCNCT(MXSS,LI)=M                                            GDH0897
            M=NCNCT(MXSS,LJ)+1                                          GDH0897
            NCNCT(M,LJ)=-LI                                             GDH0897
            NCNCT(MXSS,LJ)=M                                            GDH0897
         ENDIF                                                          GDH0897
         IF (FREEIJ) THEN                                               GDH0897
            NFREE=NFREE+1                                               GDH0897
            M=NCNCT(MXSS,LI)+1                                          GDH0897
            NCNCT(M,LI)=-LJ                                             GDH0897
            NCNCT(MXSS,LI)=M                                            GDH0897
            M=NCNCT(MXSS,LJ)+1                                          GDH0897
            NCNCT(M,LJ)=LI                                              GDH0897
            NCNCT(MXSS,LJ)=M                                            GDH0897
         ENDIF                                                          GDH0897
      ENDIF                                                             GDH0897
   80 CONTINUE                                                          GDH0897
      IF (NFREE.EQ.0) THEN                                              GDH0897
C        SPHERE K BURIED BY A CLUSTER OF SS                             GDH0897
         AREAL=0D0                                                      GDH0897
         RETURN                                                         GDH0897
      ENDIF                                                             GDH0897
C     ORIENTED ANGLES OF SLICES OF SS.                                  GDH0897
C     --------------------------------                                  GDH0897
      APOLY=0D0                                                         GDH0897
      DO 130 I=1,NCLUST                                                 GDH0897
      LI=LAB(I)                                                         GDH0897
      NPHI=NCNCT(MXSS,LI)                                               GDH0897
      IF (NPHI.EQ.0) GOTO 130                                           GDH0897
      LJ=NCNCT(1,LI)                                                    GDH0897
      IF (LJ.GT.0) THEN                                                 GDH0897
         C1=COSN1(LJ,LI)                                                GDH0897
         C2=COSN2(LJ,LI)                                                GDH0897
         C3=COSN3(LJ,LI)                                                GDH0897
      ELSE                                                              GDH0897
         LJ=-LJ                                                         GDH0897
         C1=COSN1(LI,LJ)                                                GDH0897
         C2=COSN2(LI,LJ)                                                GDH0897
         C3=COSN3(LI,LJ)                                                GDH0897
         NCNCT(1,LI)=LJ                                                 GDH0897
      ENDIF                                                             GDH0897
      SIT(LI)=1D0/STHETA(LI)                                            GDH0897
      C2I=CTHETA(LI,LI)**2                                              GDH0897
      V1=COSN2(LI,LI)*C3-COSN3(LI,LI)*C2                                GDH0897
      V2=COSN3(LI,LI)*C1-COSN1(LI,LI)*C3                                GDH0897
      V3=COSN1(LI,LI)*C2-COSN2(LI,LI)*C1                                GDH0897
      LPOLY=V1*COSN1(LJ,LJ)+V2*COSN2(LJ,LJ)+V3*COSN3(LJ,LJ).GT.0D0      GDH0897
C     MAKE A LOOP OVER THE SS I, COMPUTE DIHEDRALS BETWEEN 0 AND TWOPI  GDH0897
      DO 90 J=2,NPHI                                                    GDH0897
      LJ=NCNCT(J,LI)                                                    GDH0897
      IF (LJ.GT.0) THEN                                                 GDH0897
         CS1=COSN1(LJ,LI)                                               GDH0897
         CS2=COSN2(LJ,LI)                                               GDH0897
         CS3=COSN3(LJ,LI)                                               GDH0897
      ELSE                                                              GDH0897
         CS1=COSN1(LI,-LJ)                                              GDH0897
         CS2=COSN2(LI,-LJ)                                              GDH0897
         CS3=COSN3(LI,-LJ)                                              GDH0897
         NCNCT(J,LI)=-LJ                                                GDH0897
      ENDIF                                                             GDH0897
C     NOTE: ACCURACY IS CRUCIAL HERE (USE ATAN2, NOT ACOS OR ASIN)      GDH0897
      WORK(J-1)=ATAN2(V1*CS1+V2*CS2+V3*CS3,CS1*C1+CS2*C2+CS3*C3-C2I)    GDH0897
      IF (WORK(J-1).LE.0D0) WORK(J-1)=WORK(J-1)+TWOPI                   GDH0897
   90 CONTINUE                                                          GDH0897
      IF (NPHI.EQ.2) THEN                                               GDH0897
C        TRIVIAL CASE, NO SORT NEEDED                                   GDH0897
         AODD=WORK(1)                                                   GDH0897
      ELSE                                                              GDH0897
C        SORT THE DIHEDRALS OF SS No I IN ASCENDING ORDER               GDH0897
         DO 100 J=1,NPHI-2                                              GDH0897
         DO 100 L=J+1,NPHI-1                                            GDH0897
         IF (WORK(J).GT.WORK(L)) THEN                                   GDH0897
            BUF=WORK(L)                                                 GDH0897
            WORK(L)=WORK(J)                                             GDH0897
            WORK(J)=BUF                                                 GDH0897
            M=NCNCT(L+1,LI)                                             GDH0897
            NCNCT(L+1,LI)=NCNCT(J+1,LI)                                 GDH0897
            NCNCT(J+1,LI)=M                                             GDH0897
         ENDIF                                                          GDH0897
  100    CONTINUE                                                       GDH0897
C        COMPUTE THE SUM OF DIHEDRALS OF ORDERED SLICES (EVEN IN NUMBER)GDH0897
C        ---------------------------------------------------------------GDH0897
         AODD=WORK(1)                                                   GDH0897
         DO 110 J=3,NPHI-1,2                                            GDH0897
  110    AODD=AODD+WORK(J)-WORK(J-1)                                    GDH0897
      ENDIF                                                             GDH0897
      AEVEN=TWOPI-AODD                                                  GDH0897
      IF (LPOLY) THEN                                                   GDH0897
C        ODD DIHEDRALS ARE VERTICE OF POLYGONS                          GDH0897
         APOLY=APOLY+AODD                                               GDH0897
         ASLICE=ASLICE+AEVEN*(1.D0-CTHETA(LI,LI))                       GDH0897
      ELSE                                                              GDH0897
C        EVEN DIHEDRALS ARE VERTICE OF POLYGONS                         GDH0897
         APOLY=APOLY+AEVEN                                              GDH0897
         ASLICE=ASLICE+AODD*(1.D0-CTHETA(LI,LI))                        GDH0897
C        REORDER LABELS SO THAT POLYGON'S VERTICE APPEAR AT ODD RANKS   GDH0897
         M=NCNCT(1,LI)                                                  GDH0897
         DO 120 J=1,NPHI-1                                              GDH0897
  120    NCNCT(J,LI)=NCNCT(J+1,LI)                                      GDH0897
         NCNCT(NPHI,LI)=M                                               GDH0897
      ENDIF                                                             GDH0897
  130 CONTINUE                                                          GDH0897
C     NOW TO COUNT THE NUMBER OF POLYGONS AND TO SUM INTERSECTION ANGLESGDH0897
C     ------------------------------------------------------------------GDH0897
      NPOLY=0                                                           GDH0897
      DO 170 I=1,NCLUST                                                 GDH0897
      LI=LAB(I)                                                         GDH0897
      DO 160 J=2,NCNCT(MXSS,LI),2                                       GDH0897
      IF (NCNCT(J,LI).NE.0) THEN                                        GDH0897
C        DEFINE THE "FIRST" VERTEX OF A POLYGON                         GDH0897
         IA=NCNCT(J-1,LI)                                               GDH0897
         IB=LI                                                          GDH0897
         NCNCT(J,LI)=0                                                  GDH0897
         PHI=ACOS((CTHETA(IA,IB)-CTHETA(IA,IA)*CTHETA(IB,IB))           GDH0897
     .            *SIT(IA)*SIT(IB))                                     GDH0897
         APOLY=APOLY+PHI                                                GDH0897
C        FOLLOW AND ERASE VERTICES OF THE CURRENT POLYGON               GDH0897
  140    DO 150 L=2,NCNCT(MXSS,IA),2                                    GDH0897
         IF (NCNCT(L,IA).EQ.IB) THEN                                    GDH0897
            IBOLD=IB                                                    GDH0897
            NCNCT(L,IA)=0                                               GDH0897
            IB=IA                                                       GDH0897
            IA=NCNCT(L-1,IB)                                            GDH0897
            IF (IA.NE.IBOLD) PHI=ACOS((CTHETA(IA,IB)-CTHETA(IA,IA)*     GDH0897
     .                                 CTHETA(IB,IB))*SIT(IA)*SIT(IB))  GDH0897
            APOLY=APOLY+PHI                                             GDH0897
            GOTO 140                                                    GDH0897
         ENDIF                                                          GDH0897
  150    CONTINUE                                                       GDH0897
C        ORIENTED LOOP OVER CURRENT POLYGON COMPLETED                   GDH0897
         NPOLY=NPOLY+1                                                  GDH0897
      ENDIF                                                             GDH0897
  160 CONTINUE                                                          GDH0897
  170 CONTINUE                                                          GDH0897
C     ACCESSIBLE SOLID ANGLE FOR SPHERE K.                              GDH0897
C     ------------------------------------                              GDH0897
      APOLY=APOLY+(NPOLY-NFREE)*TWOPI                                   GDH0897
      AREAL=FOURPI-ASLICE-MOD(APOLY,FOURPI)                             GDH0897
C     POLYGONS IMBEDDED IN OTHERS TAKEN INTO ACCOUNT BY MODULO(4PI)     GDH0897
      RETURN                                                            GDH0897
      END                                                               GDH0897
