      SUBROUTINE INTCAR (GEO,COORD)                                     GDH0897
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)                               GDH0897
       INCLUDE 'SIZES.i'                                                GDH0897
       INCLUDE 'FFILES.i'                                               GDH0897
      COMMON /GEOKST/ NATOMS,LABELS(NUMATM)                             GDH0897
     .               ,NA(NUMATM),NB(NUMATM),NC(NUMATM)                  GDH0897
      DIMENSION GEO(3,*),COORD(3,*)                                     GDH0897
C***********************************************************************GDH0897
C                                                                       GDH0897
C    INTCAR  COMPUTES COORDINATES FROM BOND-ANGLES AND LENGTHS.         GDH0897
C *** IT IS ADAPTED FROM THE PROGRAM WRITTEN BY M.J.S. DEWAR.           GDH0897
C                                                                       GDH0897
C                                                                       GDH0897
C  ON INPUT:                                                            GDH0897
C         GEO    = ARRAY OF INTERNAL COORDINATES.                       GDH0897
C         NATOMS = NUMBER OF ATOMS, INCLUDING DUMMIES.                  GDH0897
C         NA     = ARRAY OF ATOM LABELS FOR BOND LENGTHS.               GDH0897
C         NB     =   "          "           ANGLES.                     GDH0897
C         NC     =   "          "           DIHEDRALS.                  GDH0897
C                                                                       GDH0897
C  ON OUTPUT:                                                           GDH0897
C         COORD  = ARRAY OF CARTESIAN COORDINATES, INCLUDING DUMMIES.   GDH0897
C                                                                       GDH0897
C  CONVENTION FOR ORIENTATION OF DIHEDRALS:                             GDH0897
C         KLYNE, PRELOG, EXPERIENCA VOL. 16, PP 521 (1960).             GDH0897
C  NOTE ... THE SAME CONVENTION IS USED IN THE FOLLOWING ROUTINES:      GDH0897
C  XYZINT, JINCAR                                                       GDH0897
C                                                                       GDH0897
C***********************************************************************GDH0897
       SAVE                                                             GDH0897
      COORD(1,1)=0.0D00                                                 GDH0897
      COORD(2,1)=0.0D00                                                 GDH0897
      COORD(3,1)=0.0D00                                                 GDH0897
      COORD(1,2)=GEO(1,2)                                               GDH0897
      COORD(2,2)=0.0D00                                                 GDH0897
      COORD(3,2)=0.0D00                                                 GDH0897
      IF(NATOMS.EQ.2) RETURN                                            GDH0897
      CCOS=COS(GEO(2,3))                                                GDH0897
      IF(NA(3).EQ.1)THEN                                                GDH0897
         COORD(1,3)=COORD(1,1)+GEO(1,3)*CCOS                            GDH0897
      ELSE                                                              GDH0897
         COORD(1,3)=COORD(1,2)-GEO(1,3)*CCOS                            GDH0897
      ENDIF                                                             GDH0897
      COORD(2,3)=GEO(1,3)*SIN(GEO(2,3))                                 GDH0897
      COORD(3,3)=0.0D00                                                 GDH0897
      DO 100 I=4,NATOMS                                                 GDH0897
         COSA=COS(GEO(2,I))                                             GDH0897
         MB=NB(I)                                                       GDH0897
         MC=NA(I)                                                       GDH0897
         XB=COORD(1,MB)-COORD(1,MC)                                     GDH0897
         YB=COORD(2,MB)-COORD(2,MC)                                     GDH0897
         ZB=COORD(3,MB)-COORD(3,MC)                                     GDH0897
         RBC=1.0D00/SQRT(XB*XB+YB*YB+ZB*ZB)                             GDH0897
         IF (ABS(COSA).LT.0.99999999991D00) GO TO 40                    GDH0897
C                                                                       GDH0897
C     ATOMS MC, MB, AND (I) ARE COLLINEAR                               GDH0897
C                                                                       GDH0897
         RBC=GEO(1,I)*RBC*COSA                                          GDH0897
         COORD(1,I)=COORD(1,MC)+XB*RBC                                  GDH0897
         COORD(2,I)=COORD(2,MC)+YB*RBC                                  GDH0897
         COORD(3,I)=COORD(3,MC)+ZB*RBC                                  GDH0897
         GO TO 100                                                      GDH0897
C                                                                       GDH0897
C     THE ATOMS ARE NOT COLLINEAR                                       GDH0897
C                                                                       GDH0897
   40    MA=NC(I)                                                       GDH0897
         XA=COORD(1,MA)-COORD(1,MC)                                     GDH0897
         YA=COORD(2,MA)-COORD(2,MC)                                     GDH0897
         ZA=COORD(3,MA)-COORD(3,MC)                                     GDH0897
C                                                                       GDH0897
C     ROTATE ABOUT THE Z-AXIS TO MAKE YB=0, AND XB POSITIVE.  IF XYB IS GDH0897
C     TOO SMALL, FIRST ROTATE THE Y-AXIS BY 90 DEGREES.                 GDH0897
C                                                                       GDH0897
         XYB=SQRT(XB*XB+YB*YB)                                          GDH0897
         K=-1                                                           GDH0897
         IF (XYB.GT.0.1D00) GO TO 50                                    GDH0897
         XPA=ZA                                                         GDH0897
         ZA=-XA                                                         GDH0897
         XA=XPA                                                         GDH0897
         XPB=ZB                                                         GDH0897
         ZB=-XB                                                         GDH0897
         XB=XPB                                                         GDH0897
         XYB=SQRT(XB*XB+YB*YB)                                          GDH0897
         K=+1                                                           GDH0897
C                                                                       GDH0897
C     ROTATE ABOUT THE Y-AXIS TO MAKE ZB VANISH                         GDH0897
C                                                                       GDH0897
   50    COSTH=XB/XYB                                                   GDH0897
         SINTH=YB/XYB                                                   GDH0897
         XPA=XA*COSTH+YA*SINTH                                          GDH0897
         YPA=YA*COSTH-XA*SINTH                                          GDH0897
         SINPH=ZB*RBC                                                   GDH0897
         COSPH=SQRT(ABS(1.D00-SINPH*SINPH))                             GDH0897
         XQA=XPA*COSPH+ZA*SINPH                                         GDH0897
         ZQA=ZA*COSPH-XPA*SINPH                                         GDH0897
C                                                                       GDH0897
C     ROTATE ABOUT THE X-AXIS TO MAKE ZA=0, AND YA POSITIVE.            GDH0897
C                                                                       GDH0897
         YZA=SQRT(YPA**2+ZQA**2)                                        GDH0897
         IF(YZA.LT.2.D-2 )THEN                                          GDH0897
            IF(YZA.LT.1.D-4)GOTO 70                                     GDH0897
            WRITE(JOUT                                                  GDH0897
     .     ,'(//20X,'' CALCULATION ABANDONED AT THIS POINT'')')         GDH0897
            WRITE(JOUT,                                                 GDH0897
     .   '(//10X,'' THREE ATOMS BEING USED TO DEFINE THE'',/            GDH0897
     110X,'' COORDINATES OF A FOURTH ATOM, WHOSE BOND-ANGLE IS'')')     GDH0897
            WRITE(JOUT,'(10X,'' NOT ZERO OR 180 DEGREEES, ARE '',       GDH0897
     1''IN AN ALMOST STRAIGHT'',/                                       GDH0897
     210X,'' LINE.  THERE IS A HIGH PROBABILITY THAT THE'',/            GDH0897
     310X,'' COORDINATES OF THE ATOM WILL BE INCORRECT.'')')            GDH0897
            WRITE(JOUT,'(//20X,''THE FAULTY ATOM IS ATOM NUMBER'',I4)')IGDH0897
            CALL GEOUT                                                  GDH0897
            WRITE(JOUT,                                                 GDH0897
     .        '(//20X,''CARTESIAN COORDINATES UP TO FAULTY ATOM'')      GDH0897
     1')                                                                GDH0897
            WRITE(JOUT,'(//5X,''I'',12X,''X'',12X,''Y'',12X,''Z'')')    GDH0897
            DO 60 J=1,I                                                 GDH0897
   60       WRITE(JOUT,'(I6,F16.5,2F13.5)')J,(COORD(K,J),K=1,3)         GDH0897
            WRITE(JOUT,'(//6X,'' ATOMS'',I3,'','',I3,'', AND'',I3,      GDH0897
     1'' ARE WITHIN'',F7.4,'' ANGSTROMS OF A STRAIGHT LINE'')')         GDH0897
     2MC,MB,MA,YZA                                                      GDH0897
         ISTOP=1                                                        GDH0897
         IWHERE=163                                                     GDH0897
         RETURN                                                         GDH0897
         ENDIF                                                          GDH0897
         COSKH=YPA/YZA                                                  GDH0897
         SINKH=ZQA/YZA                                                  GDH0897
         GOTO 80                                                        GDH0897
   70    CONTINUE                                                       GDH0897
C                                                                       GDH0897
C   ANGLE TOO SMALL TO BE IMPORTANT                                     GDH0897
C                                                                       GDH0897
         COSKH=1.D0                                                     GDH0897
         SINKH=0.D0                                                     GDH0897
   80    CONTINUE                                                       GDH0897
C                                                                       GDH0897
C     COORDINATES :-   A=(XQA,YZA,0),   B=(RBC,0,0),  C=(0,0,0)         GDH0897
C     NONE ARE NEGATIVE.                                                GDH0897
C     THE COORDINATES OF I ARE EVALUATED IN THE NEW FRAME.              GDH0897
C                                                                       GDH0897
         SINA=SIN(GEO(2,I))                                             GDH0897
         SIND=-SIN(GEO(3,I))                                            GDH0897
         COSD=COS(GEO(3,I))                                             GDH0897
         XD=GEO(1,I)*COSA                                               GDH0897
         YD=GEO(1,I)*SINA*COSD                                          GDH0897
         ZD=GEO(1,I)*SINA*SIND                                          GDH0897
C                                                                       GDH0897
C     TRANSFORM THE COORDINATES BACK TO THE ORIGINAL SYSTEM.            GDH0897
C                                                                       GDH0897
         YPD=YD*COSKH-ZD*SINKH                                          GDH0897
         ZPD=ZD*COSKH+YD*SINKH                                          GDH0897
         XPD=XD*COSPH-ZPD*SINPH                                         GDH0897
         ZQD=ZPD*COSPH+XD*SINPH                                         GDH0897
         XQD=XPD*COSTH-YPD*SINTH                                        GDH0897
         YQD=YPD*COSTH+XPD*SINTH                                        GDH0897
         IF (K.LT.1) GO TO 90                                           GDH0897
         XRD=-ZQD                                                       GDH0897
         ZQD=XQD                                                        GDH0897
         XQD=XRD                                                        GDH0897
   90    COORD(1,I)=XQD+COORD(1,MC)                                     GDH0897
         COORD(2,I)=YQD+COORD(2,MC)                                     GDH0897
         COORD(3,I)=ZQD+COORD(3,MC)                                     GDH0897
  100 CONTINUE                                                          GDH0897
      RETURN                                                            GDH0897
      END                                                               GDH0897
