#!/usr/local/bin/perl -wi

#
# OMNISOL SM5.0R-Surf Utility Program 
#

$mw=0.00;
$dandt = localtime;

#
# Read input file
#

open(IN, "<$ARGV[0]");@line="";@line=<IN>;close(IN);
$prefix = $ARGV[0]; $prefix =~ s/\.dat//i;

for $i (0 .. $#line) {
   chomp($line[$i]); $line[$i] = uc($line[$i]);
    if ($line[$i] =~ m/MW=/i) {
      ($dum,$mw) = split/MW=/,$line[$i];($mw,$dum) = split/\s+/,$mw;
    }
}
if ($mw==0.00) {
  print "Stop.  For SM5.0R-Surf calculations, the molecular weight\n";
  print "must be specified in the input file with the MW= keyword\n";
  exit;
}


# Calculate the 3D-2D dimensionality change free energy

$pi = 3.14159265;
$NA=6.02214199E23;
$k= 1.380650524E-23;
$h= 6.6262E-34;
$R= 1.987E-3;
$T= 298.15;

$mwkg = $mw/($NA*1000);

$lamda = ((2*$pi*$mwkg*$k*$T)/($h**2))**-0.5;

$dg3d2d = -$R*$T*log($lamda);

# Make input file for omnisol

open(OUT ,">$prefix.omnisolin");
print OUT "SM5.0R\n";
print OUT "& IOFR=1.342 ALPHA=1.11 BETA=0.59 GAMMA=-144.6\n";
print OUT "& FACARB=0.00 FEHALO=0.00 SOLVNT=GENORG\n";
for $i (1 .. $#line) {
   chomp($line[$i]); $line[$i] = uc($line[$i]);
   print OUT "$line[$i]\n";
}
close(OUT);

# Run job interactively

  system("OMNISOLPATHOMNISOLEXE < $prefix.omnisolin > $prefix.omnisolout 2>&1");

# Make sure calculation ran correctly. If not, stop.

if (`grep "Free energy of solvation calculated with" $prefix.omnisolout`) {
}  else {
   print "The OMNISOL calculation did not run properly.\n";
   print "Check the output file, called $prefix.log, for more details.\n";
   exit;
}

# Get the coupling free energy from the output file

open(IN,"<$prefix.omnisolout");
while(<IN>) {
    if (/ Free energy of solvation calculated with\s+([-]?\d*\.\d+)\s*/) {
      $dgcoup = $1;
    }
}
close(IN);

# Calculate Ki/a

$dgia = $dgcoup + $dg3d2d;
$logKia = (-$dgia/($R*$T))/(log(10));

#
# Clean up files.
#

`rm -f $prefix.omnisolin ; rm -f $prefix.omnisolout`;
`rm -f fort.21`;

#
# Write output.
#

open(OUT, ">$prefix.log");
print OUT << "EOF";

SM5.0R-Surf calculation, based on OMNISOL version 2.0

$dandt

EOF

for $i (0 .. $#line) {
print OUT "$line[$i]\n";
}

print OUT << "EOF";

All values are for a temperature of 298 K.
log = log(base10)
----------------------------------------------------------------------
EOF
print OUT " Coupling Free Energy (air --> water interface)\t\t";
printf OUT "%3.2f",$dgcoup;
print OUT "  kcal/mol";
print OUT "\n";
print OUT " Dimensionality Change Free Energy (3D --> 2D)\t\t";
printf OUT "%3.2f",$dg3d2d;
print OUT "  kcal/mol";
print OUT "\n";
print OUT " Adsorption Free Energy (air --> water interface)\t";
printf OUT "%3.2f",$dgia;
print OUT "  kcal/mol";
print OUT "\n";
print OUT " log Kia\t\t\t\t\t\t ";
printf OUT "%3.2f",$logKia;
print OUT "\n";
print OUT << "EOF";
----------------------------------------------------------------------

End of output.
EOF

